"""Tank IO
"""
from .massPropertiesIO import MassPropertiesIO


class TankIO:
    def __init__(self):
        self.id = None
        self.name = None
        self.position = None
        self.mass_properties = None
        self.volume = None
        self.fuel_density = None  # 810.0  # kg/m^3 Jet A1 Kerosene
        self.gravimetric_density = None  # 4.31E7 # 43 MJ/kg for kerosene
        self.energy_carrier = None
        self.max_fuel_mass_capacity = None
        self.centroid = None
        # geometry not read

    def read(self, xml_node):
        self.name = xml_node.find("./name/value").text

        my_string = xml_node.find("./designator/value").text
        new_string = my_string.replace('_', ' ')
        self.tank_location = new_string

        self.position = {
            "x": {"value": float(xml_node.find("./position/x/value").text),
                  "unit": xml_node.find("./position/x/unit").text,
                  "lower_boundary": float(xml_node.find("./position/x/lower_boundary").text),
                  "upper_boundary": float(xml_node.find("./position/x/upper_boundary").text)
                  },
            "y": {"value": float(xml_node.find("./position/y/value").text),
                  "unit": xml_node.find("./position/y/unit").text,
                  "lower_boundary": float(xml_node.find("./position/y/lower_boundary").text),
                  "upper_boundary": float(xml_node.find("./position/y/upper_boundary").text)
                  },
            "z": {"value": float(xml_node.find("./position/z/value").text),
                  "unit": xml_node.find("./position/z/unit").text,
                  "lower_boundary": float(xml_node.find("./position/z/lower_boundary").text),
                  "upper_boundary": float(xml_node.find("./position/z/upper_boundary").text)
                  }
        }

        self.centroid = {
            "x": {"value": float(xml_node.find("./mass_properties/centroid/x/value").text),
                  "unit": xml_node.find("./mass_properties/centroid/x/unit").text,
                  "lower_boundary": float(xml_node.find("./mass_properties/centroid/x/lower_boundary").text),
                  "upper_boundary": float(xml_node.find("./mass_properties/centroid/x/upper_boundary").text)
                  },
            "y": {"value": float(xml_node.find("./mass_properties/centroid/y/value").text),
                  "unit": xml_node.find("./position/y/unit").text,
                  "lower_boundary": float(xml_node.find("./mass_properties/centroid/y/lower_boundary").text),
                  "upper_boundary": float(xml_node.find("./mass_properties/centroid/y/upper_boundary").text)
                  },
            "z": {"value": float(xml_node.find("./mass_properties/centroid/z/value").text),
                  "unit": xml_node.find("./mass_properties/centroid/z/unit").text,
                  "lower_boundary": float(xml_node.find("./mass_properties/centroid/z/lower_boundary").text),
                  "upper_boundary": float(xml_node.find("./mass_properties/centroid/z/upper_boundary").text)
                  }
        }

        self.mass_properties = MassPropertiesIO(
            "./mass_properties").read(xml_node)
        self.energy = float(xml_node.find(
            "./maximum_energy_capacity/value").text)

        # self.volume = {
        #     "value": float(xml_node.find("./volume/value").text),
        #     "unit": xml_node.find("./volume/unit").text,
        #     "lower_boundary": float(xml_node.find("./volume/lower_boundary").text),
        #     "upper_boundary": float(xml_node.find("./volume/upper_boundary").text)
        # }
        return self
